==> open-cluster-management-search-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchCustomizationStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SearchCustomizationStatusFluentImpl<A extends SearchCustomizationStatusFluent<A>> extends BaseFluent<A> implements SearchCustomizationStatusFluent<A>{
  public SearchCustomizationStatusFluentImpl() {
  }
  public SearchCustomizationStatusFluentImpl(SearchCustomizationStatus instance) {
    this.withPersistence(instance.getPersistence()); 
    this.withStorageClass(instance.getStorageClass()); 
    this.withStorageSize(instance.getStorageSize()); 
  }
  private Boolean persistence;
  private String storageClass;
  private String storageSize;
  public Boolean getPersistence() {
    return this.persistence;
  }
  public A withPersistence(Boolean persistence) {
    this.persistence=persistence; return (A) this;
  }
  public Boolean hasPersistence() {
    return this.persistence != null;
  }
  public String getStorageClass() {
    return this.storageClass;
  }
  public A withStorageClass(String storageClass) {
    this.storageClass=storageClass; return (A) this;
  }
  public Boolean hasStorageClass() {
    return this.storageClass != null;
  }
  public String getStorageSize() {
    return this.storageSize;
  }
  public A withStorageSize(String storageSize) {
    this.storageSize=storageSize; return (A) this;
  }
  public Boolean hasStorageSize() {
    return this.storageSize != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SearchCustomizationStatusFluentImpl that = (SearchCustomizationStatusFluentImpl) o;
    if (persistence != null ? !persistence.equals(that.persistence) :that.persistence != null) return false;
    if (storageClass != null ? !storageClass.equals(that.storageClass) :that.storageClass != null) return false;
    if (storageSize != null ? !storageSize.equals(that.storageSize) :that.storageSize != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(persistence,  storageClass,  storageSize,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (persistence != null) { sb.append("persistence:"); sb.append(persistence + ","); }
    if (storageClass != null) { sb.append("storageClass:"); sb.append(storageClass + ","); }
    if (storageSize != null) { sb.append("storageSize:"); sb.append(storageSize); }
    sb.append("}");
    return sb.toString();
  }
  public A withPersistence() {
    return withPersistence(true);
  }
  
}

==> open-cluster-management-search-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchCustomizationStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SearchCustomizationStatusFluentImpl<A extends SearchCustomizationStatusFluent<A>> extends BaseFluent<A> implements SearchCustomizationStatusFluent<A>{
  public SearchCustomizationStatusFluentImpl() {
  }
  public SearchCustomizationStatusFluentImpl(SearchCustomizationStatus instance) {
    if (instance != null) {
      this.withPersistence(instance.getPersistence());
      this.withStorageClass(instance.getStorageClass());
      this.withStorageSize(instance.getStorageSize());
    }
  }
  private Boolean persistence;
  private String storageClass;
  private String storageSize;
  public Boolean getPersistence() {
    return this.persistence;
  }
  public A withPersistence(Boolean persistence) {
    this.persistence=persistence; return (A) this;
  }
  public Boolean hasPersistence() {
    return this.persistence != null;
  }
  public String getStorageClass() {
    return this.storageClass;
  }
  public A withStorageClass(String storageClass) {
    this.storageClass=storageClass; return (A) this;
  }
  public Boolean hasStorageClass() {
    return this.storageClass != null;
  }
  public String getStorageSize() {
    return this.storageSize;
  }
  public A withStorageSize(String storageSize) {
    this.storageSize=storageSize; return (A) this;
  }
  public Boolean hasStorageSize() {
    return this.storageSize != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SearchCustomizationStatusFluentImpl that = (SearchCustomizationStatusFluentImpl) o;
    if (!java.util.Objects.equals(persistence, that.persistence)) return false;

    if (!java.util.Objects.equals(storageClass, that.storageClass)) return false;

    if (!java.util.Objects.equals(storageSize, that.storageSize)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(persistence,  storageClass,  storageSize,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (persistence != null) { sb.append("persistence:"); sb.append(persistence + ","); }
    if (storageClass != null) { sb.append("storageClass:"); sb.append(storageClass + ","); }
    if (storageSize != null) { sb.append("storageSize:"); sb.append(storageSize); }
    sb.append("}");
    return sb.toString();
  }
  public A withPersistence() {
    return withPersistence(true);
  }
  
}
